@@ -15,10 +15,10 @@ print.aggSEMp <- function(x, estimates = FALSE, fitMeasures = FALSE, ...){
     } else if (estimates == FALSE){
       ind <- x$path_est_mat[[1]]
       colnames(ind) <- x$varnames
-      rownames(ind) <- x$varnames[(x$n_rois + 1):(x$n_rois*2)]
+      rownames(ind) <- x$varnames[(x$n_lagged+1):(x$n_vars_total)]
       ind <- round(ind, digits = 2)
-      ind_lag <- ind[ , 1:x$n_rois]
-      ind_con <- ind[ , (x$n_rois+1):(x$n_rois*2)]
+      ind_lag <- ind[ , 1:x$n_lagged]
+      ind_con <- ind[ , (x$n_lagged+1):(x$n_vars_total)]
       cat("\n")
       cat("Lagged Matrix for all", "\n")
       print(ind_lag)
